StringLexer

Struct StringLexer 

pub struct StringLexer<C, S, TK, TR: 'static, const TERMINAL_COUNT: usize> { /* private fields */ }
A lexer that operates over string inputs and uses generated string and regex recognizers provided by the parser table.

Implementations

Source

impl<'i, C: Context<'i, str, S, TK>, S: State, TK, TR: TokenRecognizer<'i>, const TERMINAL_COUNT: usize> StringLexer<C, S, TK, TR, TERMINAL_COUNT>

pub fn new( skip_ws: bool, token_recognizers: &'static [TR; TERMINAL_COUNT], ) -> Self